@@ -1,4 +1,4 @@
-PLS_lm <- function(dataY,dataX,nt=2,limQ2set=.0975,dataPredictY=dataX,modele="pls",family=NULL,typeVC="none",EstimXNA=FALSE,scaleX=TRUE,scaleY=NULL,pvals.expli=FALSE,alpha.pvals.expli=.05,MClassed=FALSE,tol_Xi=10^(-12),weights,sparse=FALSE,sparseStop=FALSE,naive=FALSE) {
+PLS_lm <- function(dataY,dataX,nt=2,limQ2set=.0975,dataPredictY=dataX,modele="pls",family=NULL,typeVC="none",EstimXNA=FALSE,scaleX=TRUE,scaleY=NULL,pvals.expli=FALSE,alpha.pvals.expli=.05,MClassed=FALSE,tol_Xi=10^(-12),weights,sparse=FALSE,sparseStop=FALSE,naive=FALSE,verbose=TRUE) {
 
 ##################################################
 #                                                #
@@ -6,7 +6,7 @@ PLS_lm <- function(dataY,dataX,nt=2,limQ2set=.0975,dataPredictY=dataX,modele="pl
 #                                                #
 ##################################################
 
-cat("____************************************************____\n")
+if(verbose){cat("____************************************************____\n")}
 if(any(apply(is.na(dataX),MARGIN=2,"all"))){return(vector("list",0)); cat("One of the columns of dataX is completely filled with missing data\n"); stop()}
 if(any(apply(is.na(dataX),MARGIN=1,"all"))){return(vector("list",0)); cat("One of the rows of dataX is completely filled with missing data\n"); stop()}
 if(identical(dataPredictY,dataX)){PredYisdataX <- TRUE} else {PredYisdataX <- FALSE}
@@ -19,8 +19,8 @@ if(missing(weights)){NoWeights=TRUE} else {if(all(weights==rep(1,length(dataY)))
 if(any(is.na(dataX))) {na.miss.X <- TRUE} else na.miss.X <- FALSE
 if(any(is.na(dataY))) {na.miss.Y <- TRUE} else na.miss.Y <- FALSE
 if(any(is.na(dataPredictY))) {na.miss.PredictY <- TRUE} else {na.miss.PredictY <- FALSE}
-if(na.miss.X|na.miss.Y){naive=TRUE; cat(paste("Only naive DoF can be used with missing data\n",sep="")); if(!NoWeights){cat(paste("Weights cannot be used with missing data\n",sep=""))};  if(sparse){cat(paste("sparse option cannot be used with missing data\n",sep="")); sparse=FALSE}}
-if(!NoWeights){naive=TRUE; cat(paste("Only naive DoF can be used with weighted PLS\n",sep=""))}
+if(na.miss.X|na.miss.Y){naive=TRUE; if(verbose){cat(paste("Only naive DoF can be used with missing data\n",sep=""))}; if(!NoWeights){if(verbose){cat(paste("Weights cannot be used with missing data\n",sep=""))}};  if(sparse){if(verbose){cat(paste("sparse option cannot be used with missing data\n",sep=""))}; sparse=FALSE}}
+if(!NoWeights){naive=TRUE; if(verbose){cat(paste("Only naive DoF can be used with weighted PLS\n",sep=""))}}
 if(sparse){sparseStop=TRUE}
 if(sparseStop){pvals.expli=TRUE}
 
@@ -115,11 +115,11 @@ temptest <- sqrt(colSums(res$residXX^2, na.rm=TRUE))
 if(any(temptest<tol_Xi)) {
 break_nt <- TRUE
 if (is.null(names(which(temptest<tol_Xi)))) {
-cat(paste("Warning : ",paste(names(which(temptest<tol_Xi)),sep="",collapse=" ")," < 10^{-12}\n",sep=""))
+  if(verbose){cat(paste("Warning : ",paste(names(which(temptest<tol_Xi)),sep="",collapse=" ")," < 10^{-12}\n",sep=""))}
 } else {
-cat(paste("Warning : ",paste((which(temptest<tol_Xi)),sep="",collapse=" ")," < 10^{-12}\n",sep=""))
+  if(verbose){cat(paste("Warning : ",paste((which(temptest<tol_Xi)),sep="",collapse=" ")," < 10^{-12}\n",sep=""))}
 }
-cat(paste("Warning only ",res$computed_nt," components could thus be extracted\n",sep=""))
+if(verbose){cat(paste("Warning only ",res$computed_nt," components could thus be extracted\n",sep=""))}
 rm(temptest)
 break
 }
@@ -161,15 +161,15 @@ res$pvalstep <- cbind(res$pvalstep,temppvalstep)
 #                                            #
 ##############################################
 if((break_nt_sparse==TRUE)&(kk==1L)){
-cat(paste("No significant predictors (<",alpha.pvals.expli,") found\n",sep=""))
-cat(paste("Warning only one standard component (without sparse option) was thus extracted\n",sep=""))
+  if(verbose){cat(paste("No significant predictors (<",alpha.pvals.expli,") found\n",sep=""))}
+  if(verbose){cat(paste("Warning only one standard component (without sparse option) was thus extracted\n",sep=""))}
 break_nt_sparse1 <- TRUE
 }
 if((break_nt_sparse==TRUE)&!(kk==1L)){
 res$computed_nt <- kk-1
 if(!(break_nt_sparse1)){
-cat(paste("No more significant predictors (<",alpha.pvals.expli,") found\n",sep=""))
-cat(paste("Warning only ",res$computed_nt," components were thus extracted\n",sep=""))
+  if(verbose){cat(paste("No more significant predictors (<",alpha.pvals.expli,") found\n",sep=""))}
+  if(verbose){cat(paste("Warning only ",res$computed_nt," components were thus extracted\n",sep=""))}
 }
 break}
 
@@ -188,8 +188,8 @@ if (na.miss.X & !na.miss.Y) {
   for (ii in 1:res$nr) {
 if(rcond(t(cbind(res$pp,temppp)[XXNA[ii,],,drop=FALSE])%*%cbind(res$pp,temppp)[XXNA[ii,],,drop=FALSE])<tol_Xi) {
 break_nt <- TRUE; res$computed_nt <- kk-1
-cat(paste("Warning : reciprocal condition number of t(cbind(res$pp,temppp)[XXNA[",ii,",],,drop=FALSE])%*%cbind(res$pp,temppp)[XXNA[",ii,",],,drop=FALSE] < 10^{-12}\n",sep=""))
-cat(paste("Warning only ",res$computed_nt," components could thus be extracted\n",sep=""))
+if(verbose){cat(paste("Warning : reciprocal condition number of t(cbind(res$pp,temppp)[XXNA[",ii,",],,drop=FALSE])%*%cbind(res$pp,temppp)[XXNA[",ii,",],,drop=FALSE] < 10^{-12}\n",sep=""))}
+if(verbose){cat(paste("Warning only ",res$computed_nt," components could thus be extracted\n",sep=""))}
 break
 }
 }
@@ -204,8 +204,8 @@ if (na.miss.PredictY & !na.miss.Y) {
 for (ii in 1:nrow(PredictYwotNA)) {
 if(rcond(t(cbind(res$pp,temppp)[PredictYNA[ii,],,drop=FALSE])%*%cbind(res$pp,temppp)[PredictYNA[ii,],,drop=FALSE])<tol_Xi) {
 break_nt <- TRUE; res$computed_nt <- kk-1
-cat(paste("Warning : reciprocal condition number of t(cbind(res$pp,temppp)[PredictYNA[",ii,",,drop=FALSE],])%*%cbind(res$pp,temppp)[PredictYNA[",ii,",,drop=FALSE],] < 10^{-12}\n",sep=""))
-cat(paste("Warning only ",res$computed_nt," components could thus be extracted\n",sep=""))
+if(verbose){cat(paste("Warning : reciprocal condition number of t(cbind(res$pp,temppp)[PredictYNA[",ii,",,drop=FALSE],])%*%cbind(res$pp,temppp)[PredictYNA[",ii,",,drop=FALSE],] < 10^{-12}\n",sep=""))}
+if(verbose){cat(paste("Warning only ",res$computed_nt," components could thus be extracted\n",sep=""))}
 break
 }
 }
@@ -290,7 +290,7 @@ if (typeVC == "none") {} else {
 if(NoWeights){
 if (typeVC %in% c("standard","adaptative")) {
 if (kk==1) {
-cat(paste("____TypeVC____",typeVC,"____\n"))
+  if(verbose){cat(paste("____TypeVC____",typeVC,"____\n"))}
 }
 temppred <- rep(0, res$nr)
 for (i in 1:(res$nr)) {     
@@ -307,7 +307,7 @@ res$press.ind2 <- cbind(res$press.ind2,(dataYwotNA-res$YChapeau-attr(res$RepY,"s
 }
 if (typeVC == "missingdata") {
 if (kk==1) {
-cat(paste("____TypeVC____",typeVC,"____\n"))
+  if(verbose){cat(paste("____TypeVC____",typeVC,"____\n"))}
 }
 temppp.cv <- res$pp  
 temppred <- rep(0, res$nr)
@@ -321,8 +321,8 @@ for (i in 1:(res$nr)) {
                 }
                 if(rcond(t(temppp.cv[XXNA[i,],,drop=FALSE])%*%temppp.cv[XXNA[i,],,drop=FALSE])<tol_Xi) {
                 break_nt_vc <- TRUE; res$computed_nt_vc <- kk-1
-                cat(paste("Warning : reciprocal condition number of t(temppp.cv[XXNA[",i,",],,drop=FALSE])%*%temppp.cv[XXNA[",i,",],,drop=FALSE]) < 10^{-12}\n",sep=""))
-                cat(paste("Please choose a smaller number of components to cross validate\n",sep=""))
+                if(verbose){cat(paste("Warning : reciprocal condition number of t(temppp.cv[XXNA[",i,",],,drop=FALSE])%*%temppp.cv[XXNA[",i,",],,drop=FALSE]) < 10^{-12}\n",sep=""))}
+                if(verbose){cat(paste("Please choose a smaller number of components to cross validate\n",sep=""))}
                 break
                 }
                 ttPredictY.cv <- (solve(t(temppp.cv[XXNA[i,],,drop=FALSE])%*%temppp.cv[XXNA[i,],,drop=FALSE])%*%t(temppp.cv[XXNA[i,],,drop=FALSE])%*%(ExpliXwotNA[i,])[XXNA[i,]])[kk]
@@ -336,7 +336,7 @@ res$press.ind2 <- cbind(res$press.ind2,(dataYwotNA-res$YChapeau-attr(res$RepY,"s
 else {
 if (typeVC %in% c("standard","adaptative")) {
 if (kk==1) {
-cat(paste("____TypeVC____",typeVC,"____\n"))
+  if(verbose){cat(paste("____TypeVC____",typeVC,"____\n"))}
 }
 temppred <- rep(0, res$nr)
 for (i in 1:(res$nr)) {     
@@ -353,7 +353,7 @@ res$press.ind2 <- cbind(res$press.ind2,weights*(dataYwotNA-res$YChapeau-attr(res
 }
 if (typeVC == "missingdata") {
 if (kk==1) {
-cat(paste("____TypeVC____",typeVC,"____\n"))
+  if(verbose){cat(paste("____TypeVC____",typeVC,"____\n"))}
 }
 temppp.cv <- res$pp  
 temppred <- rep(0, res$nr)
@@ -367,8 +367,8 @@ for (i in 1:(res$nr)) {
                 }
                 if(rcond(t(temppp.cv[XXNA[i,],,drop=FALSE])%*%temppp.cv[XXNA[i,],,drop=FALSE])<tol_Xi) {
                 break_nt_vc <- TRUE; res$computed_nt_vc <- kk-1
-                cat(paste("Warning : reciprocal condition number of t(temppp.cv[XXNA[",i,",],,drop=FALSE])%*%temppp.cv[XXNA[",i,",],,drop=FALSE]) < 10^{-12}\n",sep=""))
-                cat(paste("Please choose a smaller number of components to cross validate\n",sep=""))
+                if(verbose){cat(paste("Warning : reciprocal condition number of t(temppp.cv[XXNA[",i,",],,drop=FALSE])%*%temppp.cv[XXNA[",i,",],,drop=FALSE]) < 10^{-12}\n",sep=""))}
+                if(verbose){cat(paste("Please choose a smaller number of components to cross validate\n",sep=""))}
                 break
                 }
                 ttPredictY.cv <- (solve(t(temppp.cv[XXNA[i,],,drop=FALSE])%*%temppp.cv[XXNA[i,],,drop=FALSE])%*%t(temppp.cv[XXNA[i,],,drop=FALSE])%*%(ExpliXwotNA[i,])[XXNA[i,]])[kk]
@@ -381,7 +381,7 @@ res$press.ind2 <- cbind(res$press.ind2,weights*(dataYwotNA-res$YChapeau-attr(res
 }
 if (!(typeVC %in% c("standard","adaptative","missingdata"))) {
 if (kk==1) {
-cat(paste("____TypeVC____",typeVC,"____unknown____\n"))
+  if(verbose){cat(paste("____TypeVC____",typeVC,"____unknown____\n"))}
 }
 }
 }
@@ -438,7 +438,7 @@ if (na.miss.X & !na.miss.Y) {
 
 
 if (kk==1) {
-cat("____There are some NAs in X but not in Y____\n")
+  if(verbose){cat("____There are some NAs in X but not in Y____\n")}
 }
 
 ##############################################
@@ -449,7 +449,7 @@ if (typeVC == "none") {} else {
 if(NoWeights){
 if (typeVC %in% c("standard","missingdata")) {
 if (kk==1) {
-cat(paste("____TypeVC____",typeVC,"____\n"))
+  if(verbose){cat(paste("____TypeVC____",typeVC,"____\n"))}
 }
 temppp.cv <- res$pp  
 temppred <- rep(0, res$nr)
@@ -463,8 +463,8 @@ for (i in 1:(res$nr)) {
                 }
                 if(rcond(t(temppp.cv[XXNA[i,],,drop=FALSE])%*%temppp.cv[XXNA[i,],,drop=FALSE])<tol_Xi) {
                 break_nt_vc <- TRUE; res$computed_nt_vc <- kk-1
-                cat(paste("Warning : reciprocal condition number of t(temppp.cv[XXNA[",i,",],,drop=FALSE])%*%temppp.cv[XXNA[",i,",],,drop=FALSE]) < 10^{-12}\n",sep=""))
-                cat(paste("Please choose a smaller number of components to cross validate\n",sep=""))
+                if(verbose){cat(paste("Warning : reciprocal condition number of t(temppp.cv[XXNA[",i,",],,drop=FALSE])%*%temppp.cv[XXNA[",i,",],,drop=FALSE]) < 10^{-12}\n",sep=""))}
+                if(verbose){cat(paste("Please choose a smaller number of components to cross validate\n",sep=""))}
                 break
                 }
                 ttPredictY.cv <- (solve(t(temppp.cv[XXNA[i,],,drop=FALSE])%*%temppp.cv[XXNA[i,],,drop=FALSE])%*%t(temppp.cv[XXNA[i,],,drop=FALSE])%*%(XXwotNA[i,])[XXNA[i,]])[kk]
@@ -475,7 +475,7 @@ res$press.ind2 <- cbind(res$press.ind2,(dataYwotNA-res$YChapeau-attr(res$RepY,"s
 }
 if (typeVC == "adaptative") {
 if (kk==1) {
-cat(paste("____TypeVC____",typeVC,"____\n"))
+  if(verbose){cat(paste("____TypeVC____",typeVC,"____\n"))}
 }
 temppp.cv <- res$pp  
 temppred <- rep(0, res$nr)
@@ -498,8 +498,8 @@ else {
                 }
                 if(rcond(t(temppp.cv[XXNA[i,],,drop=FALSE])%*%temppp.cv[XXNA[i,],,drop=FALSE])<tol_Xi) {
                 break_nt_vc <- TRUE; res$computed_nt_vc <- kk-1
-                cat(paste("Warning : reciprocal condition number of t(temppp.cv[XXNA[",i,",],,drop=FALSE])%*%temppp.cv[XXNA[",i,",],,drop=FALSE]) < 10^{-12}\n",sep=""))
-                cat(paste("Please choose a smaller number of components to cross validate\n",sep=""))
+                if(verbose){cat(paste("Warning : reciprocal condition number of t(temppp.cv[XXNA[",i,",],,drop=FALSE])%*%temppp.cv[XXNA[",i,",],,drop=FALSE]) < 10^{-12}\n",sep=""))}
+                if(verbose){cat(paste("Please choose a smaller number of components to cross validate\n",sep=""))}
                 break
                 }
                 ttPredictY.cv <- (solve(t(temppp.cv[XXNA[i,],,drop=FALSE])%*%temppp.cv[XXNA[i,],,drop=FALSE])%*%t(temppp.cv[XXNA[i,],,drop=FALSE])%*%(XXwotNA[i,])[XXNA[i,]])[kk]
@@ -511,14 +511,14 @@ res$press.ind2 <- cbind(res$press.ind2,(dataYwotNA-res$YChapeau-attr(res$RepY,"s
 }
 if (!(typeVC %in% c("standard","missingdata","adaptative"))) {
 if (kk==1) {
-cat(paste("____TypeVC____",typeVC,"____unknown____\n"))
+  if(verbose){cat(paste("____TypeVC____",typeVC,"____unknown____\n"))}
 }
 }
 }
 else {
 if (typeVC %in% c("standard","missingdata")) {
 if (kk==1) {
-cat(paste("____TypeVC____",typeVC,"____\n"))
+  if(verbose){cat(paste("____TypeVC____",typeVC,"____\n"))}
 }
 temppp.cv <- res$pp  
 temppred <- rep(0, res$nr)
@@ -532,8 +532,8 @@ for (i in 1:(res$nr)) {
                 }
                 if(rcond(t(temppp.cv[XXNA[i,],,drop=FALSE])%*%temppp.cv[XXNA[i,],,drop=FALSE])<tol_Xi) {
                 break_nt_vc <- TRUE; res$computed_nt_vc <- kk-1
-                cat(paste("Warning : reciprocal condition number of t(temppp.cv[XXNA[",i,",],,drop=FALSE])%*%temppp.cv[XXNA[",i,",],,drop=FALSE]) < 10^{-12}\n",sep=""))
-                cat(paste("Please choose a smaller number of components to cross validate\n",sep=""))
+                if(verbose){cat(paste("Warning : reciprocal condition number of t(temppp.cv[XXNA[",i,",],,drop=FALSE])%*%temppp.cv[XXNA[",i,",],,drop=FALSE]) < 10^{-12}\n",sep=""))}
+                if(verbose){cat(paste("Please choose a smaller number of components to cross validate\n",sep=""))}
                 break
                 }
                 ttPredictY.cv <- (solve(t(temppp.cv[XXNA[i,],,drop=FALSE])%*%temppp.cv[XXNA[i,],,drop=FALSE])%*%t(temppp.cv[XXNA[i,],,drop=FALSE])%*%(XXwotNA[i,])[XXNA[i,]])[kk]
@@ -544,7 +544,7 @@ res$press.ind2 <- cbind(res$press.ind2,weights*(dataYwotNA-res$YChapeau-attr(res
 }
 if (typeVC == "adaptative") {
 if (kk==1) {
-cat(paste("____TypeVC____",typeVC,"____\n"))
+  if(verbose){cat(paste("____TypeVC____",typeVC,"____\n"))}
 }
 temppp.cv <- res$pp  
 temppred <- rep(0, res$nr)
@@ -567,8 +567,8 @@ else {
                 }
                 if(rcond(t(temppp.cv[XXNA[i,],,drop=FALSE])%*%temppp.cv[XXNA[i,],,drop=FALSE])<tol_Xi) {
                 break_nt_vc <- TRUE; res$computed_nt_vc <- kk-1
-                cat(paste("Warning : reciprocal condition number of t(temppp.cv[XXNA[",i,",],,drop=FALSE])%*%temppp.cv[XXNA[",i,",],,drop=FALSE]) < 10^{-12}\n",sep=""))
-                cat(paste("Please choose a smaller number of components to cross validate\n",sep=""))
+                if(verbose){cat(paste("Warning : reciprocal condition number of t(temppp.cv[XXNA[",i,",],,drop=FALSE])%*%temppp.cv[XXNA[",i,",],,drop=FALSE]) < 10^{-12}\n",sep=""))}
+                if(verbose){cat(paste("Please choose a smaller number of components to cross validate\n",sep=""))}
                 break
                 }
                 ttPredictY.cv <- (solve(t(temppp.cv[XXNA[i,],,drop=FALSE])%*%temppp.cv[XXNA[i,],,drop=FALSE])%*%t(temppp.cv[XXNA[i,],,drop=FALSE])%*%(XXwotNA[i,])[XXNA[i,]])[kk]
@@ -580,7 +580,7 @@ res$press.ind2 <- cbind(res$press.ind2,weights*(dataYwotNA-res$YChapeau-attr(res
 }
 if (!(typeVC %in% c("standard","missingdata","adaptative"))) {
 if (kk==1) {
-cat(paste("____TypeVC____",typeVC,"____unknown____\n"))
+  if(verbose){cat(paste("____TypeVC____",typeVC,"____unknown____\n"))}
 }
 }
 }
@@ -630,7 +630,7 @@ res$RSS <- cbind(res$RSS,crossprod(res$Yresidus,weights*res$Yresidus))
 
 else {
 if (kk==1) {
-cat("____There are some NAs both in X and Y____\n")
+  if(verbose){cat("____There are some NAs both in X and Y____\n")}
 }
 }
 }
@@ -689,7 +689,7 @@ rm(tempCoeffs)
 rm(tempConstante)
 }
 
-cat("____Component____",kk,"____\n")
+if(verbose){cat("____Component____",kk,"____\n")}
 if(break_nt_vc==TRUE) {break}
 }
 
@@ -703,7 +703,7 @@ if(break_nt_vc==TRUE) {break}
 ##############################################
 
 if(res$computed_nt==0){
-cat("No component could be extracted please check the data for NA only lines or columns\n"); stop()
+  cat("No component could be extracted please check the data for NA only lines or columns\n"); stop()
 }
 
 ##############################################
@@ -715,13 +715,13 @@ cat("No component could be extracted please check the data for NA only lines or
 
 
 if (!(na.miss.PredictY | na.miss.Y)) {
-cat("____Predicting X without NA neither in X nor in Y____\n")
+  if(verbose){cat("____Predicting X without NA neither in X nor in Y____\n")}
 res$ttPredictY <- PredictYwotNA%*%res$wwetoile 
 colnames(res$ttPredictY) <- paste("Comp_",1:res$computed_nt,sep="")
 }
 else {
 if (na.miss.PredictY & !na.miss.Y) {
-cat("____Predicting X with NA in X and not in Y____\n")
+  if(verbose){cat("____Predicting X with NA in X and not in Y____\n")}
 
 for (ii in 1:nrow(PredictYwotNA)) {  
       res$ttPredictY <- rbind(res$ttPredictY,t(solve(t(res$pp[PredictYNA[ii,],,drop=FALSE])%*%res$pp[PredictYNA[ii,],,drop=FALSE])%*%t(res$pp[PredictYNA[ii,],,drop=FALSE])%*%(PredictYwotNA[ii,])[PredictYNA[ii,]]))
@@ -729,7 +729,7 @@ for (ii in 1:nrow(PredictYwotNA)) {
 colnames(res$ttPredictY) <- paste("Comp_",1:res$computed_nt,sep="")
 }
 else {
-cat("____There are some NAs both in X and Y____\n")
+  if(verbose){cat("____There are some NAs both in X and Y____\n")}
 }
 }
 
@@ -834,7 +834,7 @@ colnames(res$wwetoile) <- paste("Coord_Comp_",1:res$computed_nt,sep="")
 rownames(res$tt) <- rownames(ExpliX)
 colnames(res$tt) <- paste("Comp_",1:res$computed_nt,sep="")
 res$XXwotNA <- XXwotNA
-cat("****________________________________________________****\n")
-cat("\n")
+if(verbose){cat("****________________________________________________****\n")}
+if(verbose){cat("\n")}
 return(res)
 }
